__halves2half2
Applicability
Product |
Supported |
|---|---|
Atlas 350 Accelerator Card |
√ |
x |
|
x |
|
x |
|
x |
|
x |
|
x |
Function Usage
Fills the input data into the front and rear components of half2 and returns the filled data.
Prototype
1 | inline half2 __halves2half2(const half x, const half y) |
Parameters
Parameter |
Input/Output |
Description |
|---|---|---|
x |
Input |
Source operand. |
y |
Input |
Source operand. |
Returns
Result of filling the input data into the front and rear components of half2
Restrictions
For SIMT programming, this API is not supported.
Header Files to Be Included
To use this API, the simt_api/asc_fp16.h header file must be included.
1 | #include "simt_api/asc_fp16.h" |
Examples
For SIMD and SIMT programming:
1 2 3 4 5 6 7 8 9 10 11 12 13 | // Use small vectors to improve data movement efficiency. __simt_vf__ __launch_bounds__(1024) inline void simt_halves2half2(__gm__ half* input1, __gm__ half* input2, __gm__ half2* output, uint32_t input_total_length) { uint32_t idx = blockIdx.x * blockDim.x + threadIdx.x; if (idx > input_total_length) { return; } output[idx] = __halves2half2(input1[idx], input2[idx]); } __global__ __vector__ void cast_kernel(__gm__ half* input1, __gm__ half* input2, __gm__ half* output, uint32_t input_total_length) { asc_vf_call<simt_halves2half2>(dim3(1024), input1, input2, (__gm__ half2*)output, input_total_length); } |
Parent topic: Type Conversion